@@ -424,7 +424,7 @@ class WPlotManager(Ui_WPlotManager, QWidget):
             Minimum value for Z axis (or Y if only one axe)
         frozen_type : int
             0 to let the user modify the axis of the plot, 1 to let him switch them, 2 to not let him change them,
-            3 to freeze both axes and operations, 4 to freeze fft, 5 to only allow switch
+            3 to freeze both axes and operations, 4 to freeze fft, 5 to only allow switch, 6 to only allow overlay button
         plot_arg_dict : dict
             Dictionnary with arguments that must be given to the plot (used for animated plot)
         save_path : str
